@@ -7,32 +7,12 @@ use aliased 'Google::RestApi::SheetsApi4::RangeGroup::Iterator';
 
 use parent qw(Test::Unit::TestBase);
 
-sub setup : Tests(setup) {
-  my $self = shift;
-  $self->SUPER::setup(@_);
-
-  $self->_fake_http_auth();
-  $self->_fake_http_no_retries();
-
-  $self->_uri_responses(qw(
-    get_spreadsheet_named_ranges
-    get_worksheet_properties_title_sheetid
-    get_worksheet_values_cell
-    get_worksheet_values_row
-    get_worksheet_values_a1_c3
-    post_worksheet_values_x_y_z
-    put_worksheet_values_a1_c3
-  ));
-
-  return;
-}
+init_logger;
 
 sub iterate : Test(9) {
   my $self = shift;
 
-  $self->_fake_http_response_by_uri();
-
-  my $ws0 = fake_worksheet();
+  my $ws0 = $self->mock_worksheet();
   $ws0->enable_header_row();
 
   my @values = (
